@@ -18,5 +18,7 @@ from datameta_client_lib.api.authentication_and_users_api import AuthenticationA
 from datameta_client_lib.api.files_api import FilesApi
 from datameta_client_lib.api.groups_api import GroupsApi
 from datameta_client_lib.api.metadata_api import MetadataApi
+from datameta_client_lib.api.remote_procedure_calls_api import RemoteProcedureCallsApi
+from datameta_client_lib.api.server_api import ServerApi
 from datameta_client_lib.api.settings_api import SettingsApi
 from datameta_client_lib.api.submissions_api import SubmissionsApi
